@@ -802,8 +802,8 @@ SAVERS = {
 @gen.coroutine
 def _head_object(context, bucket, key):
     credentials = yield context.s3_auth()
-    s3_client = boto3.client('s3', aws_access_key_id=credentials.aws_access_key_id,
-                             aws_secret_access_key=credentials.aws_secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
+    s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
     response = s3_client.head_object(Bucket=bucket, Key=key)
     if 'ContentLength' in response and response['ContentLength'] >= 0:
         return True
@@ -813,43 +813,42 @@ def _head_object(context, bucket, key):
 @gen.coroutine
 def _put_object(context, bucket, body, object_name):
     credentials = yield context.s3_auth()
-    s3_client = boto3.client('s3', aws_access_key_id=credentials.aws_access_key_id,
-                             aws_secret_access_key=credentials.aws_secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")    # Upload the file
+    s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
     return s3_client.put_object(Body=body, Bucket=bucket, Key=object_name)
 
 @gen.coroutine
 def _get_object(context, bucket, object_name):
     credentials = yield context.s3_auth()
-    s3_client = boto3.client('s3', aws_access_key_id=credentials.aws_access_key_id,
-                             aws_secret_access_key=credentials.aws_secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")    # Download the file
+    s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
     return s3_client.get_object(Bucket=bucket, Key=object_name)
 
 @gen.coroutine
 def _list_buckets(context):
     # Retrieve the list of existing buckets
     credentials = yield context.s3_auth()
-    s3_client = boto3.client('s3', aws_access_key_id=credentials.aws_access_key_id,
-                             aws_secret_access_key=credentials.aws_secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
+    s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
     return s3_client.list_buckets()
 
 @gen.coroutine
 def _copy_object(context, bucket, source_file, destination_file):
     credentials = yield context.s3_auth()
-    s3_client = boto3.client('s3', aws_access_key_id=credentials.aws_access_key_id,
-                             aws_secret_access_key=credentials.aws_secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
+    s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
     return s3_client.copy_object(Bucket=bucket, CopySource=source_file, Key=destination_file)
 
 @gen.coroutine
 def _delete_object(context, bucket, file_name):
     credentials = yield context.s3_auth()
-    s3_client = boto3.client('s3', aws_access_key_id=credentials.aws_access_key_id,
-                             aws_secret_access_key=credentials.aws_secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
+    s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
     return s3_client.delete_object(Bucket=bucket, Key=file_name)
 
 @gen.coroutine
 def _list_objects(context, bucket, prefix, delimiter, max_keys, token=''):
     credentials = yield context.s3_auth()
-    print(credentials)
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
                              aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
     if token:
